@@ -47,6 +47,15 @@ class DuckDBConnectionWrapper:
     def cursor(self):
         return self
 
+    def execute(self, sql, bindings=None):
+        try:
+            if bindings is None:
+                return self._conn.execute(sql)
+            else:
+                return self._conn.execute(sql, bindings)
+        except RuntimeError as e:
+            raise dbt.exceptions.RuntimeException(str(e))
+
 
 class DuckDBConnectionManager(SQLConnectionManager):
     TYPE = "duckdb"
@@ -78,19 +87,6 @@ class DuckDBConnectionManager(SQLConnectionManager):
     def cancel(self, connection):
         pass
 
-    def add_query(
-        self,
-        sql: str,
-        auto_begin: bool = True,
-        bindings: Optional[Any] = None,
-        abridge_sql_log: bool = False,
-    ) -> Tuple[Connection, Any]:
-        # Work around error that is thrown with None bindings in
-        # duckdb/sqlite
-        if bindings is None:
-            bindings = []
-        return super().add_query(sql, auto_begin, bindings, abridge_sql_log)
-
     @contextmanager
     def exception_handler(self, sql: str, connection_name="master"):
         try:
